import com.silanis.esl.sdk.external.signer.verification.domain.response.SignerVerificationResponse;
import com.silanis.esl.sdk.external.signer.verification.domain.response.SignerVerificationResponsePayload;
import com.silanis.esl.sdk.external.signer.verification.processor.DefaultSignerVerificationProcessorFactory;
import com.silanis.esl.sdk.external.signer.verification.processor.SignerVerificationConfig;
import com.silanis.esl.sdk.external.signer.verification.processor.SignerVerificationProcessor;
import com.silanis.esl.sdk.external.signer.verification.processor.SignerVerificationProcessorFactory;
import com.silanis.esl.sdk.external.signer.verification.processor.jwt.HmacJwtSignerVerificationConfig;

import java.net.URISyntaxException;
import java.util.UUID;

public class VerificationResponseTokenConversion {
    private static final String SIGNING_SHARED_SECRET = "signing secret";
    private static final String ENCRYPTION_SHARED_SECRET = "encryption secret";
    private static final SignerVerificationProcessor signerVerificationProcessor;

    static {
        SignerVerificationConfig signerVerificationConfig = new HmacJwtSignerVerificationConfig(SIGNING_SHARED_SECRET, ENCRYPTION_SHARED_SECRET);
        SignerVerificationProcessorFactory signerVerificationProcessorFactory = new DefaultSignerVerificationProcessorFactory();
        signerVerificationProcessor = signerVerificationProcessorFactory.createSignerVerificationProcessor(signerVerificationConfig);
    }

    public static void main(String[] args) throws URISyntaxException {
        String signerVerificationResponseToken = retrieveSignerVerificationResponseToken();
        SignerVerificationResponse signerVerificationResponse = signerVerificationProcessor.toSignerVerificationResponse(new SignerVerificationResponsePayload(signerVerificationResponseToken));

        String documentIdentificationInfo = signerVerificationResponse.getDocumentIdentificationInfo(); //eSignLive will have to parse it to extract the info for the document that the signer would like to confirm
        String confirmationPayload = signerVerificationResponse.getConfirmationPayload();
        boolean verified = signerVerificationResponse.isVerified();

        if (verified) {
            //verify document with the info extracted from documentIdentificationInfo
            //if everything is OK, confirm the document
        }
    }

    /**
     For the actual implementation in the eSignLive Application Backend, this should extract the Signer Verification Response Token from the redirect URL.
     Here, we simply generate a sample token so that we can show how to convert it to a SignerVerificationResponse object in the main method above.
     */
    private static String retrieveSignerVerificationResponseToken() {
        SignerVerificationResponse signerVerificationResponse = new SignerVerificationResponse()
                .setDocumentIdentificationInfo(UUID.randomUUID().toString())
                .setConfirmationPayload(UUID.randomUUID().toString())
                .setVerified(true);

        return signerVerificationProcessor.toSignerVerificationResponsePayload(signerVerificationResponse).getValue();
    }
}
